hepstats.modeling.bayesian\_blocks module
=========================================

.. automodule:: hepstats.modeling.bayesian_blocks
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
